==> analyzer-3.2.0.tar.gz: test/src/diagnostics/mixin_inherits_from_not_object_test.dart <==
// Copyright (c) 2019, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:analyzer/src/error/codes.dart';
import 'package:test_reflective_loader/test_reflective_loader.dart';

import '../dart/resolution/context_collection_resolution.dart';

main() {
  defineReflectiveSuite(() {
    defineReflectiveTests(MixinInheritsFromNotObjectTest);
  });
}

@reflectiveTest
class MixinInheritsFromNotObjectTest extends PubPackageResolutionTest {
  test_classAlias_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
class B extends A {}
class C = Object with B;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 54, 1),
    ]);
  }

  test_classAlias_class_with() async {
    await assertErrorsInCode(r'''
class A {}
class B extends Object with A {}
class C = Object with B;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 66, 1),
    ]);
  }

  test_classAlias_classAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
class B = Object with A;
class C = Object with B;
''');
  }

  test_classAlias_classAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
class C = Object with A, B;
class D = Object with C;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 72, 1),
    ]);
  }

  test_classAlias_mixin() async {
    await assertNoErrorsInCode(r'''
class A {}
mixin B on A {}
class C = A with B;
''');
  }

  test_classDeclaration_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
class B extends A {}
class C extends Object with B {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 60, 1),
    ]);
  }

  test_classDeclaration_class_extends_Object() async {
    await assertNoErrorsInCode(r'''
class A {}
class B extends Object {}
class C extends Object with B {}
''');
  }

  test_classDeclaration_class_with() async {
    await assertErrorsInCode(r'''
class A {}
class B extends Object with A {}
class C extends Object with B {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 72, 1),
    ]);
  }

  test_classDeclaration_classAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
class B = Object with A;
class C extends Object with B {}
''');
  }

  test_classDeclaration_classAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
class C = Object with A, B;
class D extends Object with C {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 78, 1),
    ]);
  }

  test_classDeclaration_mixin() async {
    await assertNoErrorsInCode(r'''
class A {}
mixin B on A {}
class C extends A with B {}
''');
  }
}

==> analyzer-5.6.0.tar.gz: test/src/diagnostics/mixin_inherits_from_not_object_test.dart <==
// Copyright (c) 2019, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:analyzer/src/error/codes.dart';
import 'package:test_reflective_loader/test_reflective_loader.dart';

import '../dart/resolution/context_collection_resolution.dart';

main() {
  defineReflectiveSuite(() {
    defineReflectiveTests(MixinInheritsFromNotObjectTest);
  });
}

@reflectiveTest
class MixinInheritsFromNotObjectTest extends PubPackageResolutionTest {
  test_class_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
class B extends A {}
class C extends Object with B {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 60, 1),
    ]);
  }

  test_class_class_extends_Object() async {
    await assertNoErrorsInCode(r'''
class A {}
class B extends Object {}
class C extends Object with B {}
''');
  }

  test_class_class_with() async {
    await assertErrorsInCode(r'''
class A {}
class B extends Object with A {}
class C extends Object with B {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 72, 1),
    ]);
  }

  test_class_classTypeAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
class B = Object with A;
class C extends Object with B {}
''');
  }

  test_class_classTypeAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
class C = Object with A, B;
class D extends Object with C {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 78, 1),
    ]);
  }

  test_class_mixin() async {
    await assertNoErrorsInCode(r'''
class A {}
mixin B on A {}
class C extends A with B {}
''');
  }

  test_classTypeAlias_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
class B extends A {}
class C = Object with B;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 54, 1),
    ]);
  }

  test_classTypeAlias_class_with() async {
    await assertErrorsInCode(r'''
class A {}
class B extends Object with A {}
class C = Object with B;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 66, 1),
    ]);
  }

  test_classTypeAlias_classAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
class B = Object with A;
class C = Object with B;
''');
  }

  test_classTypeAlias_classAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
class C = Object with A, B;
class D = Object with C;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 72, 1),
    ]);
  }

  test_classTypeAlias_mixin() async {
    await assertNoErrorsInCode(r'''
class A {}
mixin B on A {}
class C = A with B;
''');
  }

  test_enum_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
class B extends A {}
enum E with B {
  v
}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 44, 1),
    ]);
  }

  test_enum_class_extends_Object() async {
    await assertNoErrorsInCode(r'''
class A {}
class B extends Object {}
enum E with B {
  v
}
''');
  }

  test_enum_class_with() async {
    await assertErrorsInCode(r'''
class A {}
class B extends Object with A {}
enum E with B {
  v
}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 56, 1),
    ]);
  }

  test_enum_classTypeAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
class B = Object with A;
enum E with B {
  v
}
''');
  }

  test_enum_classTypeAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
class C = Object with A, B;
enum E with C {
  v
}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 62, 1),
    ]);
  }

  test_mixinClass_class_extends() async {
    await assertErrorsInCode(r'''
class A {}
mixin class B extends A {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 33, 1),
    ]);
  }

  test_mixinClass_class_extends_Object() async {
    await assertNoErrorsInCode(r'''
mixin class A extends Object {}
''');
  }

  test_mixinClass_class_extends_Object_with() async {
    await assertErrorsInCode(r'''
class A {}
mixin class B extends Object with A {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 40, 6),
    ]);
  }

  test_mixinClass_class_with() async {
    await assertErrorsInCode(r'''
class A {}
mixin class B with A {}
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 25, 6),
    ]);
  }

  test_mixinClass_classTypeAlias_with() async {
    await assertNoErrorsInCode(r'''
class A {}
mixin class B = Object with A;
''');
  }

  test_mixinClass_classTypeAlias_with2() async {
    await assertErrorsInCode(r'''
class A {}
class B {}
mixin class C = Object with A, B;
''', [
      error(CompileTimeErrorCode.MIXIN_INHERITS_FROM_NOT_OBJECT, 45, 9),
    ]);
  }
}
